@@ -23,25 +23,27 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <DLog>
-
-#include "lockframe.h"
-#include "dbuslockfrontservice.h"
+#include "accessibilitycheckerex.h"
+#include "appeventfilter.h"
 #include "dbuslockagent.h"
+#include "dbuslockfrontservice.h"
 #include "dbusshutdownagent.h"
 #include "dbusshutdownfrontservice.h"
-#include "multiscreenmanager.h"
-
 #include "lockcontent.h"
+#include "lockframe.h"
 #include "lockworker.h"
-#include "sessionbasemodel.h"
+#include "modules_loader.h"
+#include "multiscreenmanager.h"
 #include "propertygroup.h"
+#include "sessionbasemodel.h"
 
-#include <QDBusInterface>
+#include <DApplication>
 #include <DGuiApplicationHelper>
+#include <DLog>
 #include <DPlatformTheme>
 
-#include <dapplication.h>
+#include <QDBusInterface>
+
 #include <unistd.h>
 
 DCORE_USE_NAMESPACE
@@ -62,8 +64,10 @@ int main(int argc, char *argv[])
     app->setApplicationName("dde-lock");
     app->setApplicationVersion("2015.1.0");
 
-    // crash catch
-    init_sig_crash();
+    //注册全局事件过滤器
+    AppEventFilter appEventFilter;
+    app->installEventFilter(&appEventFilter);
+    setAppType(APP_TYPE_LOCK);
 
     DGuiApplicationHelper::instance()->setPaletteType(DGuiApplicationHelper::LightType);
     DPalette pa = DGuiApplicationHelper::instance()->applicationPalette();
@@ -93,9 +97,11 @@ int main(int argc, char *argv[])
     DLogManager::registerConsoleAppender();
     DLogManager::registerFileAppender();
 
-    QTranslator translator;
-    translator.load("/usr/share/dde-session-shell/translations/dde-session-shell_" + QLocale::system().name());
-    app->installTranslator(&translator);
+    /* load translation files */
+    loadTranslation(QLocale::system().name());
+
+    dss::module::ModulesLoader *modulesLoader = &dss::module::ModulesLoader::instance();
+    modulesLoader->start(QThread::LowestPriority);
 
     QCommandLineParser cmdParser;
     cmdParser.addHelpOption();
@@ -124,10 +130,19 @@ int main(int argc, char *argv[])
     showLockScreen = true;
 #endif
 
-    SessionBaseModel *model = new SessionBaseModel(SessionBaseModel::AuthType::LockType);
+    SessionBaseModel *model = new SessionBaseModel();
+    model->setAppType(Lock);
     LockWorker *worker = new LockWorker(model);
+    QObject::connect(&appEventFilter, &AppEventFilter::userIsActive, worker, &LockWorker::restartResetSessionTimer);
     PropertyGroup *property_group = new PropertyGroup(worker);
 
+    if (worker->isLocked()) {
+        //如果当前Session被锁定，则启动dde-lock时直接进入锁屏状态
+        //兼容在desktop文件中添加-l启动参数来解决杀掉dde-lock后启动器无法打开的问题,BUG91126
+        //同时避免在desktop文件中添加-l启动参数在正常启动时就直接进入锁屏而无法调用任务栏关机按钮中接口的问题,BUG92030
+        showLockScreen = true;
+    }
+
     property_group->addProperty("contentVisible");
 
     DBusLockAgent lockAgent;
@@ -138,23 +153,26 @@ int main(int argc, char *argv[])
     shutdownAgent.setModel(model);
     DBusShutdownFrontService shutdownServices(&shutdownAgent);
 
-    auto createFrame = [&] (QScreen *screen) -> QWidget* {
+    auto createFrame = [&] (QScreen *screen, int count) -> QWidget* {
         LockFrame *lockFrame = new LockFrame(model);
-        lockFrame->setScreen(screen);
+        lockFrame->setScreen(screen, count <= 0);
         property_group->addObject(lockFrame);
         QObject::connect(lockFrame, &LockFrame::requestSwitchToUser, worker, &LockWorker::switchToUser);
-        QObject::connect(lockFrame, &LockFrame::requestAuthUser, worker, &LockWorker::authUser);
         QObject::connect(model, &SessionBaseModel::visibleChanged, lockFrame, &LockFrame::setVisible);
         QObject::connect(model, &SessionBaseModel::visibleChanged, lockFrame,[&](bool visible) {
             emit lockService.Visible(visible);
         });
-        QObject::connect(lockFrame, &LockFrame::requestSetLayout, worker, &LockWorker::setLayout);
+        QObject::connect(lockFrame, &LockFrame::requestSetLayout, worker, &LockWorker::setKeyboardLayout);
         QObject::connect(lockFrame, &LockFrame::requestEnableHotzone, worker, &LockWorker::enableZoneDetected, Qt::UniqueConnection);
         QObject::connect(lockFrame, &LockFrame::destroyed, property_group, &PropertyGroup::removeObject);
         QObject::connect(lockFrame, &LockFrame::sendKeyValue, [&](QString key) {
              emit lockService.ChangKey(key);
         });
-        lockFrame->setVisible(model->isShow());
+        QObject::connect(lockFrame, &LockFrame::requestStartAuthentication, worker, &LockWorker::startAuthentication);
+        QObject::connect(lockFrame, &LockFrame::sendTokenToAuth, worker, &LockWorker::sendTokenToAuth);
+        QObject::connect(lockFrame, &LockFrame::requestEndAuthentication, worker, &LockWorker::endAuthentication);
+        QObject::connect(lockFrame, &LockFrame::authFinished, worker, &LockWorker::onAuthFinished);
+        lockFrame->setVisible(model->visible());
         emit lockService.Visible(true);
         return lockFrame;
     };
@@ -162,9 +180,19 @@ int main(int argc, char *argv[])
     MultiScreenManager multi_screen_manager;
     multi_screen_manager.register_for_mutil_screen(createFrame);
 
+#if defined(DSS_CHECK_ACCESSIBILITY) && defined(QT_DEBUG)
+    AccessibilityCheckerEx checker;
+    //Dtk::Widget::DBlurEffectWidget 添加accessibleName、objectName都会检查出内存泄露，原因不知
+    checker.addIgnoreClasses(QStringList()
+                          << "Dtk::Widget::DBlurEffectWidget");
+    checker.setOutputFormat(DAccessibilityChecker::FullFormat);
+    checker.start();
+#endif
+
     QObject::connect(model, &SessionBaseModel::visibleChanged, &multi_screen_manager, &MultiScreenManager::startRaiseContentFrame);
 
     QDBusConnection conn = QDBusConnection::sessionBus();
+    int ret = 0;
     if (!conn.registerService(DBUS_LOCK_NAME) ||
         !conn.registerObject(DBUS_LOCK_PATH, &lockAgent) ||
         !conn.registerService(DBUS_SHUTDOWN_NAME) ||
@@ -196,7 +224,7 @@ int main(int argc, char *argv[])
                 emit model->showLockScreen();
             }
         }
-        app->exec();
+        ret = app->exec();
     }
-    return 0;
+    return ret;
 }
