@@ -1,89 +1,116 @@
 #include "lockcontent.h"
 
+#include "base_module_interface.h"
 #include "controlwidget.h"
-#include "sessionbasemodel.h"
-#include "userframe.h"
-#include "shutdownwidget.h"
-#include "virtualkbinstance.h"
 #include "logowidget.h"
+#include "mfa_widget.h"
+#include "modules_loader.h"
+#include "sessionbasemodel.h"
+#include "sfa_widget.h"
+#include "shutdownwidget.h"
 #include "timewidget.h"
-#include "userlogininfo.h"
-#include "userloginwidget.h"
 #include "userframelist.h"
+#include "virtualkbinstance.h"
 
-#include <QMouseEvent>
 #include <DDBusSender>
 
+#include <QLocalSocket>
+#include <QMouseEvent>
+
+using namespace dss;
+using namespace dss::module;
+
 LockContent::LockContent(SessionBaseModel *const model, QWidget *parent)
     : SessionBaseWindow(parent)
     , m_model(model)
     , m_virtualKB(nullptr)
-    , m_translator(new QTranslator)
-    , m_userLoginInfo(new UserLoginInfo(model, this))
     , m_wmInter(new com::deepin::wm("com.deepin.wm", "/com/deepin/wm", QDBusConnection::sessionBus(), this))
+    , m_sfaWidget(nullptr)
+    , m_mfaWidget(nullptr)
+    , m_authWidget(nullptr)
+    , m_userListWidget(nullptr)
+    , m_localServer(new QLocalServer(this))
 {
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
 
+    initUI();
+    initConnections();
+
+    if (model->appType() == Lock) {
+        setMPRISEnable(model->currentModeState() != SessionBaseModel::ModeStatus::ShutDownMode);
+    }
+
+    QTimer::singleShot(0, this, [=] {
+        onCurrentUserChanged(model->currentUser());
+        onUserListChanged(model->isServerModel() ? model->loginedUserList() : model->userList());
+    });
+
+    m_localServer->setMaxPendingConnections(1);
+    m_localServer->setSocketOptions(QLocalServer::WorldAccessOption);
+    static bool once = false;
+    if (!once) {
+        if (!m_localServer->listen("GrabKeyboard")) { // 监听特定的连接
+            qWarning() << "listen failed!" << m_localServer->errorString();
+            if(m_localServer->serverError() == QAbstractSocket::AddressInUseError) {
+                QLocalServer::removeServer("GrabKeyboard");
+                if (!m_localServer->listen("GrabKeyboard")) {
+                    qWarning() << "listen failed again!" << m_localServer->serverName() << m_localServer->errorString();
+                } else {
+                    qDebug() << "listen success!";
+                }
+            }
+        } else {
+            qDebug() << "listen success!";
+        }
+    }
+    once = true;
+}
+
+void LockContent::initUI()
+{
     m_timeWidget = new TimeWidget();
+    m_timeWidget->setAccessibleName("TimeWidget");
     setCenterTopWidget(m_timeWidget);
     // 处理时间制跳转策略，获取到时间制再显示时间窗口
     m_timeWidget->setVisible(false);
 
     m_shutdownFrame = new ShutdownWidget;
-    m_shutdownFrame->setModel(model);
+    m_shutdownFrame->setAccessibleName("ShutdownFrame");
+    m_shutdownFrame->setModel(m_model);
 
     m_logoWidget = new LogoWidget;
+    m_logoWidget->setAccessibleName("LogoWidget");
     setLeftBottomWidget(m_logoWidget);
 
-    m_controlWidget = new ControlWidget;
+    m_controlWidget = new ControlWidget(m_model);
+    m_controlWidget->setAccessibleName("ControlWidget");
     setRightBottomWidget(m_controlWidget);
 
-    switch (model->currentType()) {
-    case SessionBaseModel::AuthType::LockType:
-        setMPRISEnable(model->currentModeState() != SessionBaseModel::ModeStatus::ShutDownMode);
-        break;
-    default:
-        break;
+    if (m_model->getAuthProperty().MFAFlag) {
+        initMFAWidget();
+    } else {
+        initSFAWidget();
     }
+    m_authWidget->hide();
 
-    // init connect
-    connect(m_userLoginInfo, &UserLoginInfo::accountLineEditFinished, this, [ = ](const QString &accountName) {
-        auto user_ptr = m_model->findUserByName(accountName);
-        if (user_ptr != nullptr) {
-            auto locale = user_ptr->locale();
-            m_logoWidget->updateLocale(locale);
-            m_timeWidget->updateLocale(locale);
-            m_userLoginInfo->updateUserLoginLocale(locale);
-            m_localeFlag = true;
-        } else if (m_localeFlag) {
-            QLocale locale;
-            m_logoWidget->updateLocale(locale.name());
-            m_timeWidget->updateLocale(locale.name());
-             m_userLoginInfo->updateUserLoginLocale(locale);
-            m_localeFlag = false;
-        }
-    });
-    connect(model, &SessionBaseModel::currentUserChanged, this, &LockContent::onCurrentUserChanged);
+    initUserListWidget();
+}
+
+void LockContent::initConnections()
+{
+    connect(m_model, &SessionBaseModel::currentUserChanged, this, &LockContent::onCurrentUserChanged);
     connect(m_controlWidget, &ControlWidget::requestSwitchUser, this, [ = ] {
-        if (m_model->currentModeState() == SessionBaseModel::ModeStatus::UserMode) return;
         m_model->setCurrentModeState(SessionBaseModel::ModeStatus::UserMode);
+        emit requestEndAuthentication(m_model->currentUser()->name(), AT_All);
     });
     connect(m_controlWidget, &ControlWidget::requestShutdown, this, [ = ] {
         m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PowerMode);
     });
     connect(m_controlWidget, &ControlWidget::requestSwitchVirtualKB, this, &LockContent::toggleVirtualKB);
-    connect(m_userLoginInfo, &UserLoginInfo::requestAuthUser, this, &LockContent::requestAuthUser);
-    connect(m_userLoginInfo, &UserLoginInfo::hideUserFrameList, this, &LockContent::restoreMode);
-    connect(m_userLoginInfo, &UserLoginInfo::requestSwitchUser, this, &LockContent::requestSwitchToUser);
-    connect(m_userLoginInfo, &UserLoginInfo::switchToCurrentUser, this, &LockContent::restoreMode);
-    connect(m_userLoginInfo, &UserLoginInfo::requestSetLayout, this, &LockContent::requestSetLayout);
-    connect(m_userLoginInfo, &UserLoginInfo::unlockActionFinish, this, [&]{
-        emit unlockActionFinish();
-    });
+    connect(m_controlWidget, &ControlWidget::requestShowModule, this, &LockContent::showModule);
 
     //刷新背景单独与onStatusChanged信号连接，避免在showEvent事件时调用onStatusChanged而重复刷新背景，减少刷新次数
-    connect(model, &SessionBaseModel::onStatusChanged, this, &LockContent::refreshBackground);
-    connect(model, &SessionBaseModel::onStatusChanged, this, &LockContent::onStatusChanged);
+    connect(m_model, &SessionBaseModel::onStatusChanged, this, &LockContent::onStatusChanged);
 
     //在锁屏显示时，启动onborad进程，锁屏结束时结束onboard进程
     auto initVirtualKB = [&](bool hasvirtualkb) {
@@ -100,36 +127,95 @@ LockContent::LockContent(SessionBaseModel *const model, QWidget *parent)
         }
     };
 
-    connect(model, &SessionBaseModel::hasVirtualKBChanged, this, initVirtualKB, Qt::QueuedConnection);
-    connect(model, &SessionBaseModel::onUserListChanged, this, &LockContent::onUserListChanged);
-    connect(model, &SessionBaseModel::userListLoginedChanged, this, &LockContent::onUserListChanged);
-    connect(model, &SessionBaseModel::authFinished, this, &LockContent::restoreMode);
-    connect(model, &SessionBaseModel::switchUserFinished, this, [ = ] {
-        QTimer::singleShot(100, this, [ = ] {
-            emit LockContent::restoreMode();
-        });
-    });
-
-    QTimer::singleShot(0, this, [ = ] {
-        onCurrentUserChanged(model->currentUser());
-        onUserListChanged(model->isServerModel() ? model->logindUser() : model->userList());
+    connect(m_model, &SessionBaseModel::hasVirtualKBChanged, this, initVirtualKB, Qt::QueuedConnection);
+    connect(m_model, &SessionBaseModel::userListChanged, this, &LockContent::onUserListChanged);
+    connect(m_model, &SessionBaseModel::userListLoginedChanged, this, &LockContent::onUserListChanged);
+    connect(m_model, &SessionBaseModel::authFinished, this, &LockContent::restoreMode);
+    connect(m_model, &SessionBaseModel::MFAFlagChanged, this, [this](const bool isMFA) {
+        isMFA ? initMFAWidget() : initSFAWidget();
+        // 当前中间窗口为空或者中间窗口就是验证窗口的时候显示验证窗口
+        if (!m_centerWidget || m_centerWidget == m_authWidget)
+            setCenterContent(m_authWidget, Qt::AlignTop, m_authWidget->getTopSpacing());
     });
 
     connect(m_wmInter, &__wm::WorkspaceSwitched, this, &LockContent::currentWorkspaceChanged);
+    connect(m_localServer, &QLocalServer::newConnection, this, &LockContent::onNewConnection);
+}
+
+/**
+ * @brief 初始化多因认证界面
+ */
+void LockContent::initMFAWidget()
+{
+    qDebug() << "LockContent::initMFAWidget:" << m_sfaWidget << m_mfaWidget;
+    if (m_sfaWidget) {
+        m_sfaWidget->hide();
+        delete m_sfaWidget;
+        m_sfaWidget = nullptr;
+    }
+    if (m_mfaWidget) {
+        m_authWidget = m_mfaWidget;
+        return;
+    }
+    m_mfaWidget = new MFAWidget(this);
+    m_mfaWidget->setModel(m_model);
+    m_authWidget = m_mfaWidget;
+
+    connect(m_mfaWidget, &MFAWidget::requestStartAuthentication, this, &LockContent::requestStartAuthentication);
+    connect(m_mfaWidget, &MFAWidget::sendTokenToAuth, this, &LockContent::sendTokenToAuth);
+    connect(m_mfaWidget, &MFAWidget::requestEndAuthentication, this, &LockContent::requestEndAuthentication);
+    connect(m_mfaWidget, &MFAWidget::requestCheckAccount, this, &LockContent::requestCheckAccount);
+}
+
+/**
+ * @brief 初始化单因认证界面
+ */
+void LockContent::initSFAWidget()
+{
+    qDebug() << "LockContent::initSFAWidget:" << m_sfaWidget << m_mfaWidget;
+    if (m_mfaWidget) {
+        m_mfaWidget->hide();
+        delete m_mfaWidget;
+        m_mfaWidget = nullptr;
+    }
+    if (m_sfaWidget) {
+        m_authWidget = m_sfaWidget;
+        return;
+    }
+    m_sfaWidget = new SFAWidget(this);
+    m_sfaWidget->setModel(m_model);
+    m_authWidget = m_sfaWidget;
+
+    connect(m_sfaWidget, &SFAWidget::requestStartAuthentication, this, &LockContent::requestStartAuthentication);
+    connect(m_sfaWidget, &SFAWidget::sendTokenToAuth, this, &LockContent::sendTokenToAuth);
+    connect(m_sfaWidget, &SFAWidget::requestEndAuthentication, this, &LockContent::requestEndAuthentication);
+    connect(m_sfaWidget, &SFAWidget::requestCheckAccount, this, &LockContent::requestCheckAccount);
+    connect(m_sfaWidget, &SFAWidget::authFinished, this, &LockContent::authFinished);
+}
+
+/**
+ * @brief 初始化用户列表界面
+ */
+void LockContent::initUserListWidget()
+{
+    if (m_userListWidget) {
+        return;
+    }
+    m_userListWidget = new UserFrameList(this);
+    m_userListWidget->setModel(m_model);
+
+    connect(m_userListWidget, &UserFrameList::clicked, this, &LockContent::restoreMode);
+    connect(m_userListWidget, &UserFrameList::requestSwitchUser, this, &LockContent::requestSwitchToUser);
 }
 
 void LockContent::onCurrentUserChanged(std::shared_ptr<User> user)
 {
     if (user.get() == nullptr) return; // if dbus is async
 
-    // set user language
-    qApp->removeTranslator(m_translator);
-    const QString locale { user->locale().split(".").first() };
-    m_translator->load("/usr/share/dde-session-shell/translations/dde-session-shell_" + QLocale(locale.isEmpty() ? "en_US" : locale).name());
-    qApp->installTranslator(m_translator);
-
-    m_logoWidget->updateLocale(user->locale());
-    m_timeWidget->updateLocale(user->locale());
+    //如果是锁屏就用系统语言，如果是登陆界面就用用户语言
+    auto locale = qApp->applicationName() == "dde-lock" ? QLocale::system().name() : user->locale();
+    m_logoWidget->updateLocale(locale);
+    m_timeWidget->updateLocale(locale);
 
     for (auto connect : m_currentUserConnects) {
         m_user.get()->disconnect(connect);
@@ -139,69 +225,48 @@ void LockContent::onCurrentUserChanged(std::shared_ptr<User> user)
 
     m_user = user;
 
-    std::shared_ptr<NativeUser> nativeUser = std::dynamic_pointer_cast<NativeUser>(user);
-    UserInter *userInter = nullptr;
-    if (!nativeUser) {
-        m_timeWidget->setVisible(true);
-        qDebug() << "trans to NativeUser user failed, user:" << user->metaObject()->className();
-    } else {
-        userInter = nativeUser->getUserInter();
-    }
+    m_timeWidget->set24HourFormat(user->isUse24HourFormat());
+    m_timeWidget->setWeekdayFormatType(user->weekdayFormat());
+    m_timeWidget->setShortDateFormat(user->shortDateFormat());
+    m_timeWidget->setShortTimeFormat(user->shortTimeFormat());
 
-    m_currentUserConnects << connect(user.get(), &User::greeterBackgroundPathChanged, this, &LockContent::updateGreeterBackgroundPath, Qt::UniqueConnection)
-                          << connect(user.get(), &User::desktopBackgroundPathChanged, this, &LockContent::updateDesktopBackgroundPath, Qt::UniqueConnection)
+    m_currentUserConnects << connect(user.get(), &User::greeterBackgroundChanged, this, &LockContent::updateGreeterBackgroundPath, Qt::UniqueConnection)
+                          << connect(user.get(), &User::desktopBackgroundChanged, this, &LockContent::updateDesktopBackgroundPath, Qt::UniqueConnection)
                           << connect(user.get(), &User::use24HourFormatChanged, this, &LockContent::updateTimeFormat, Qt::UniqueConnection)
-                          << connect(userInter, &UserInter::WeekdayFormatChanged, m_timeWidget, &TimeWidget::setWeekdayFormatType)
-                          << connect(userInter, &UserInter::ShortDateFormatChanged, m_timeWidget, &TimeWidget::setShortDateFormat)
-                          << connect(userInter, &UserInter::ShortTimeFormatChanged, m_timeWidget, &TimeWidget::setShortTimeFormat);
-
-    //lixin
-    m_userLoginInfo->setUser(user);
+                          << connect(user.get(), &User::weekdayFormatChanged, m_timeWidget, &TimeWidget::setWeekdayFormatType)
+                          << connect(user.get(), &User::shortDateFormatChanged, m_timeWidget, &TimeWidget::setShortDateFormat)
+                          << connect(user.get(), &User::shortTimeFormatChanged, m_timeWidget, &TimeWidget::setShortTimeFormat);
 
     //TODO: refresh blur image
     QTimer::singleShot(0, this, [ = ] {
-        if (userInter) {
-            userInter->weekdayFormat();
-            userInter->shortDateFormat();
-            userInter->shortTimeFormat();
-        }
-
-        // 异步刷新界面时间格式
-        user->is24HourFormat();
-        updateTimeFormat(user->is24HourFormat());
-
-        //获取用户后，刷新界面背景图片
-        m_user->greeterBackgroundPath();
-        m_user->desktopBackgroundPath();
+        updateTimeFormat(user->isUse24HourFormat());
     });
 
-    m_logoWidget->updateLocale(m_user->locale());
+    m_logoWidget->updateLocale(locale);
 }
 
 void LockContent::pushPasswordFrame()
 {
-    auto current_user = m_model->currentUser();
+    setCenterContent(m_authWidget, Qt::AlignTop, m_authWidget->getTopSpacing());
 
-    setCenterContent(m_userLoginInfo->getUserLoginWidget());
-
-    // hide keyboardlayout widget
-    m_userLoginInfo->hideKBLayout();
+    SFAWidget *sfaWidget = qobject_cast<SFAWidget *>(m_authWidget);
+    if (sfaWidget) {
+        sfaWidget->syncResetPasswordUI();
+    }
 }
 
 void LockContent::pushUserFrame()
 {
     if(m_model->isServerModel())
         m_controlWidget->setUserSwitchEnable(false);
-    //设置用户列表大小为中间区域的大小,并移动到左上角，避免显示后出现移动现象
-    UserFrameList * userFrameList = m_userLoginInfo->getUserFrameList();
-    userFrameList->setFixedSize(getCenterContentSize());
-    userFrameList->move(0, 0);
-    setCenterContent(m_userLoginInfo->getUserFrameList());
+
+    m_userListWidget->updateLayout();
+    setCenterContent(m_userListWidget);
 }
 
 void LockContent::pushConfirmFrame()
 {
-    setCenterContent(m_userLoginInfo->getUserLoginWidget());
+    setCenterContent(m_authWidget, Qt::AlignTop, m_authWidget->getTopSpacing());
 }
 
 void LockContent::pushShutdownFrame()
@@ -218,6 +283,7 @@ void LockContent::setMPRISEnable(const bool state)
 {
     if (!m_mediaWidget) {
         m_mediaWidget = new MediaWidget;
+        m_mediaWidget->setAccessibleName("MediaWidget");
         m_mediaWidget->initMediaPlayer();
     }
 
@@ -225,9 +291,24 @@ void LockContent::setMPRISEnable(const bool state)
     setCenterBottomWidget(m_mediaWidget);
 }
 
-void LockContent::beforeUnlockAction(bool is_finish)
+void LockContent::onNewConnection()
 {
-    m_userLoginInfo->beforeUnlockAction(is_finish);
+    if (m_localServer->hasPendingConnections()) {
+        QLocalSocket *socket = m_localServer->nextPendingConnection();
+        connect(socket, &QLocalSocket::disconnected, this, &LockContent::onDisConnect);
+        connect(socket, &QLocalSocket::readyRead, this, [socket, this]{
+            auto content = socket->readAll();
+            if (content == "close") {
+                m_sfaWidget->syncPasswordResetPasswordVisibleChanged(QVariant::fromValue(true));
+                m_sfaWidget->syncResetPasswordUI();
+            }
+        });
+    }
+}
+
+void LockContent::onDisConnect()
+{
+    tryGrabKeyboard();
 }
 
 void LockContent::onStatusChanged(SessionBaseModel::ModeStatus status)
@@ -235,7 +316,7 @@ void LockContent::onStatusChanged(SessionBaseModel::ModeStatus status)
     refreshLayout(status);
 
     if(m_model->isServerModel())
-        onUserListChanged(m_model->logindUser());
+        onUserListChanged(m_model->loginedUserList());
     switch (status) {
     case SessionBaseModel::ModeStatus::PasswordMode:
         pushPasswordFrame();
@@ -255,15 +336,30 @@ void LockContent::onStatusChanged(SessionBaseModel::ModeStatus status)
     }
 
     m_model->setAbortConfirm(status == SessionBaseModel::ModeStatus::ConfirmPasswordMode);
+    if (status != SessionBaseModel::ModeStatus::ConfirmPasswordMode)
+        m_model->setPowerAction(SessionBaseModel::PowerAction::None);
 }
 
 void LockContent::mouseReleaseEvent(QMouseEvent *event)
 {
+    // 如果是设置密码界面，不做处理
+    if (m_model->currentModeState() == SessionBaseModel::ResetPasswdMode)
+        return SessionBaseWindow::mouseReleaseEvent(event);
+
     //在关机界面没有点击按钮直接点击界面时，直接隐藏关机界面
     if (m_model->currentModeState() == SessionBaseModel::ShutDownMode) {
         hideToplevelWindow();
     }
 
+    if (m_model->currentModeState() == SessionBaseModel::UserMode) {
+        // 触屏点击空白处不退出用户列表界面
+        if (event->source() == Qt::MouseEventSynthesizedByQt)
+            return SessionBaseWindow::mouseReleaseEvent(event);
+
+        // 点击空白处的时候切换到当前用户，以开启验证。
+        emit requestSwitchToUser(m_model->currentUser());
+    }
+
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
 
     return SessionBaseWindow::mouseReleaseEvent(event);
@@ -272,7 +368,6 @@ void LockContent::mouseReleaseEvent(QMouseEvent *event)
 void LockContent::showEvent(QShowEvent *event)
 {
     onStatusChanged(m_model->currentModeState());
-
     tryGrabKeyboard();
     return QFrame::showEvent(event);
 }
@@ -286,13 +381,17 @@ void LockContent::hideEvent(QHideEvent *event)
 void LockContent::resizeEvent(QResizeEvent *event)
 {
     QTimer::singleShot(0, this, [ = ] {
-        if (m_virtualKB && m_virtualKB->isVisible())
-        {
+        if (m_virtualKB && m_virtualKB->isVisible()) {
             updateVirtualKBPosition();
         }
     });
 
-    return QFrame::resizeEvent(event);
+    if (SessionBaseModel::PasswordMode == m_model->currentModeState() || (SessionBaseModel::ConfirmPasswordMode == m_model->currentModeState())) {
+        m_centerSpacerItem->changeSize(0, m_authWidget->getTopSpacing());
+        m_centerVLayout->update();
+    }
+
+    return SessionBaseWindow::resizeEvent(event);
 }
 
 void LockContent::restoreMode()
@@ -325,7 +424,8 @@ void LockContent::updateDesktopBackgroundPath(const QString &path)
 void LockContent::updateTimeFormat(bool use24)
 {
     if (m_user != nullptr) {
-        m_timeWidget->updateLocale(m_user->locale());
+        auto locale = qApp->applicationName() == "dde-lock" ? QLocale::system().name() : m_user->locale();
+        m_timeWidget->updateLocale(locale);
         m_timeWidget->set24HourFormat(use24);
         m_timeWidget->setVisible(true);
     }
@@ -345,12 +445,32 @@ void LockContent::toggleVirtualKB()
 
     m_virtualKB->setParent(this);
     m_virtualKB->raise();
-    m_userLoginInfo->getUserLoginWidget()->setPassWordEditFocus();
+    // m_userLoginInfo->getUserLoginWidget()->setPassWordEditFocus();
 
     updateVirtualKBPosition();
     m_virtualKB->setVisible(!m_virtualKB->isVisible());
 }
 
+void LockContent::showModule(const QString &name)
+{
+    BaseModuleInterface *module = ModulesLoader::instance().findModuleByName(name);
+    if (!module) {
+        return;
+    }
+
+    switch (module->type()) {
+    case BaseModuleInterface::LoginType:
+        m_loginWidget = module->content();
+        setCenterContent(m_loginWidget);
+        m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
+        break;
+    case BaseModuleInterface::TrayType:
+        m_loginWidget = module->content();
+        setCenterContent(m_loginWidget);
+        break;
+    }
+}
+
 void LockContent::updateVirtualKBPosition()
 {
     const QPoint point = mapToParent(QPoint((width() - m_virtualKB->width()) / 2, height() - m_virtualKB->height() - 50));
@@ -363,8 +483,8 @@ void LockContent::onUserListChanged(QList<std::shared_ptr<User> > list)
     const bool alwaysShowUserSwitchButton = m_model->alwaysShowUserSwitchButton();
     bool haveLogindUser = true;
 
-    if (m_model->isServerModel() && m_model->currentType() == SessionBaseModel::LightdmType) {
-        haveLogindUser = !m_model->logindUser().isEmpty();
+    if (m_model->isServerModel() && m_model->appType() == Login) {
+        haveLogindUser = !m_model->loginedUserList().isEmpty();
     }
 
     bool enable = (alwaysShowUserSwitchButton ||
@@ -382,6 +502,9 @@ void LockContent::tryGrabKeyboard()
     return;
 #endif
 
+    if (qgetenv("XDG_SESSION_TYPE").contains("wayland"))
+        return;
+
     if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(true)) {
         m_failures = 0;
         return;
@@ -391,25 +514,23 @@ void LockContent::tryGrabKeyboard()
 
     if (m_failures == 15) {
         qDebug() << "Trying grabkeyboard has exceeded the upper limit. dde-lock will quit.";
-        m_model->setLocked(false);
 
         DDBusSender()
-                .service("org.freedesktop.Notifications")
-                .path("/org/freedesktop/Notifications")
-                .interface("org.freedesktop.Notifications")
-                .method(QString("Notify"))
-                .arg(tr("Lock Screen"))
-                .arg(static_cast<uint>(0))
-                .arg(QString(""))
-                .arg(QString(""))
-                .arg(tr("Failed to lock screen"))
-                .arg(QStringList())
-                .arg(QVariantMap())
-                .arg(5000)
-                .call();
+            .service("org.freedesktop.Notifications")
+            .path("/org/freedesktop/Notifications")
+            .interface("org.freedesktop.Notifications")
+            .method(QString("Notify"))
+            .arg(tr("Lock Screen"))
+            .arg(static_cast<uint>(0))
+            .arg(QString(""))
+            .arg(QString(""))
+            .arg(tr("Failed to lock screen"))
+            .arg(QStringList())
+            .arg(QVariantMap())
+            .arg(5000)
+            .call();
 
-        qApp->quit();
-        return;
+        hide();
     }
 
     QTimer::singleShot(100, this, &LockContent::tryGrabKeyboard);
@@ -457,14 +578,12 @@ void LockContent::updateWallpaper(const QString &path)
 
 void LockContent::refreshBackground(SessionBaseModel::ModeStatus status)
 {
-    //根据当前状态刷新不同的背景
+    Q_UNUSED(status)
+
+    // 根据当前状态刷新不同的背景
     auto user = m_model->currentUser();
     if (user != nullptr) {
-        if (status == SessionBaseModel::ModeStatus::ShutDownMode) {
-            emit requestBackground(user->desktopBackgroundPath());
-        } else {
-            emit requestBackground(user->greeterBackgroundPath());
-        }
+        emit requestBackground(user->greeterBackground());
     }
 }
 
@@ -477,9 +596,16 @@ void LockContent::refreshLayout(SessionBaseModel::ModeStatus status)
 void LockContent::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
+    case Qt::Key_Return ... Qt::Key_Enter: {
+        if (m_mfaWidget) {
+            m_mfaWidget->autoUnlock();
+        }
+        break;
+    }
     case Qt::Key_Escape: {
         if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ConfirmPasswordMode) {
             m_model->setAbortConfirm(false);
+            m_model->setPowerAction(SessionBaseModel::PowerAction::None);
         } else if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
             hideToplevelWindow();
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
