@@ -1,17 +1,21 @@
 #include "sessionbasewindow.h"
+#include "constants.h"
 
 #include <QDebug>
 #include <QResizeEvent>
 #include <QApplication>
 
+using namespace DDESESSIONCC;
+
 SessionBaseWindow::SessionBaseWindow(QWidget *parent)
     : QFrame(parent)
     , m_centerTopFrame(nullptr)
     , m_centerFrame(nullptr)
     , m_bottomFrame(nullptr)
-    , m_mainLayou(nullptr)
+    , m_mainLayout(nullptr)
     , m_centerTopLayout(nullptr)
     , m_centerLayout(nullptr)
+    , m_centerVLayout(nullptr)
     , m_leftBottomLayout(nullptr)
     , m_centerBottomLayout(nullptr)
     , m_rightBottomLayout(nullptr)
@@ -20,6 +24,7 @@ SessionBaseWindow::SessionBaseWindow(QWidget *parent)
     , m_leftBottomWidget(nullptr)
     , m_centerBottomWidget(nullptr)
     , m_rightBottomWidget(nullptr)
+    , m_centerSpacerItem(new QSpacerItem(0, 0))
 {
     initUI();
 }
@@ -53,23 +58,23 @@ void SessionBaseWindow::setRightBottomWidget(QWidget * const widget)
     m_rightBottomWidget = widget;
 }
 
-void SessionBaseWindow::setCenterContent(QWidget * const widget)
+void SessionBaseWindow::setCenterContent(QWidget * const widget, Qt::AlignmentFlag align, int spacerHeight)
 {
-    if (m_centerWidget == widget)
+    if (!widget || m_centerWidget == widget) {
         return;
-
-    if (m_centerWidget != nullptr) {
+    }
+    if (m_centerWidget) {
         m_centerLayout->removeWidget(m_centerWidget);
         m_centerWidget->hide();
-        m_centerWidget->setParent(nullptr);
     }
-    m_centerWidget = widget;
+    m_centerLayout->addWidget(widget, 0, align);
+    m_centerSpacerItem->changeSize(0, spacerHeight);
 
-    //Minimum 布局中部件大小是最小值并且是足够大的。而部件允许扩展，并不一定要扩展，但是不能比缺省大小更小
-    m_centerWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    m_centerLayout->addWidget(m_centerWidget, 0, Qt::AlignCenter);
-    m_centerWidget->setFocus();
-    m_centerWidget->show();
+    m_centerWidget = widget;
+    widget->show();
+
+    setFocusProxy(widget);
+    setFocus();
 }
 
 void SessionBaseWindow::setCenterTopWidget(QWidget *const widget)
@@ -92,16 +97,24 @@ void SessionBaseWindow::initUI()
     m_centerTopLayout->setSpacing(0);
 
     m_centerTopFrame = new QFrame;
+    m_centerTopFrame->setAccessibleName("CenterTopFrame");
     m_centerTopFrame->setLayout(m_centerTopLayout);
-    m_centerTopFrame->setFixedHeight(132);
+    m_centerTopFrame->setFixedHeight(LOCK_CONTENT_TOP_WIDGET_HEIGHT);
     m_centerTopFrame->setAutoFillBackground(false);
 
     m_centerLayout = new QHBoxLayout;
     m_centerLayout->setMargin(0);
     m_centerLayout->setSpacing(0);
 
+    m_centerVLayout = new QVBoxLayout;
+    m_centerVLayout->setMargin(0);
+    m_centerVLayout->setSpacing(0);
+    m_centerVLayout->addSpacerItem(m_centerSpacerItem);
+    m_centerVLayout->addLayout(m_centerLayout);
+
     m_centerFrame = new QFrame;
-    m_centerFrame->setLayout(m_centerLayout);
+    m_centerFrame->setAccessibleName("CenterFrame");
+    m_centerFrame->setLayout(m_centerVLayout);
     m_centerFrame->setAutoFillBackground(false);
 
     m_leftBottomLayout = new QHBoxLayout;
@@ -118,31 +131,32 @@ void SessionBaseWindow::initUI()
     QHBoxLayout *bottomLayout = new QHBoxLayout;
     bottomLayout->setMargin(0);
     bottomLayout->setSpacing(0);
-    bottomLayout->addLayout(m_leftBottomLayout, 1);
-    bottomLayout->addLayout(m_centerBottomLayout, 3);
-    bottomLayout->addLayout(m_rightBottomLayout, 1);
+    bottomLayout->addLayout(m_leftBottomLayout, 3);
+    bottomLayout->addLayout(m_centerBottomLayout, 2);
+    bottomLayout->addLayout(m_rightBottomLayout, 3);
 
     m_bottomFrame = new QFrame;
+    m_bottomFrame->setAccessibleName("BottomFrame");
     m_bottomFrame->setLayout(bottomLayout);
-    m_bottomFrame->setFixedHeight(132);
+    m_bottomFrame->setFixedHeight(LOCK_CONTENT_TOP_WIDGET_HEIGHT);
     m_bottomFrame->setAutoFillBackground(false);
 
-    m_mainLayou = new QVBoxLayout;
-    m_mainLayou->setContentsMargins(0, 33, 0, 33);
-    m_mainLayou->setSpacing(0);
-    m_mainLayou->addWidget(m_centerTopFrame);
-    m_mainLayou->addWidget(m_centerFrame);
-    m_mainLayou->addWidget(m_bottomFrame);
+    m_mainLayout = new QVBoxLayout;
+    m_mainLayout->setContentsMargins(0, LOCK_CONTENT_CENTER_LAYOUT_MARGIN, 0, LOCK_CONTENT_CENTER_LAYOUT_MARGIN);
+    m_mainLayout->setSpacing(0);
+    m_mainLayout->addWidget(m_centerTopFrame);
+    m_mainLayout->addWidget(m_centerFrame);
+    m_mainLayout->addWidget(m_bottomFrame);
 
-    setLayout(m_mainLayou);
+    setLayout(m_mainLayout);
 }
 
 QSize SessionBaseWindow::getCenterContentSize()
 {
     //计算中间区域的大小
-    int w = width() - m_mainLayou->contentsMargins().left() - m_mainLayou->contentsMargins().right();
+    int w = width() - m_mainLayout->contentsMargins().left() - m_mainLayout->contentsMargins().right();
 
-    int h = height() - m_mainLayou->contentsMargins().top() - m_mainLayou->contentsMargins().bottom();
+    int h = height() - m_mainLayout->contentsMargins().top() - m_mainLayout->contentsMargins().bottom();
     if (m_centerTopFrame->isVisible()) {
         h = h - m_centerTopFrame->height();
     }
@@ -153,6 +167,11 @@ QSize SessionBaseWindow::getCenterContentSize()
     return QSize(w, h);
 }
 
+void SessionBaseWindow::resizeEvent(QResizeEvent *event)
+{
+    QFrame::resizeEvent(event);
+}
+
 void SessionBaseWindow::setTopFrameVisible(bool visible)
 {
     m_centerTopFrame->setVisible(visible);
@@ -162,4 +181,3 @@ void SessionBaseWindow::setBottomFrameVisible(bool visible)
 {
     m_bottomFrame->setVisible(visible);
 }
-
