@@ -3,6 +3,8 @@
 
 #include <QFrame>
 #include <QVBoxLayout>
+#include <QPointer>
+#include <QSpacerItem>
 
 class SessionBaseWindow : public QFrame
 {
@@ -12,32 +14,35 @@ public:
     virtual void setLeftBottomWidget(QWidget *const widget) final;
     virtual void setCenterBottomWidget(QWidget *const widget) final;
     virtual void setRightBottomWidget(QWidget *const widget) final;
-    virtual void setCenterContent(QWidget *const widget) final;
+    virtual void setCenterContent(QWidget *const widget, Qt::AlignmentFlag align = Qt::AlignCenter, int spacerHeight = 0) final;
     virtual void setCenterTopWidget(QWidget *const widget) final;
     QSize getCenterContentSize();
 
 protected:
     void setTopFrameVisible(bool visible);
     void setBottomFrameVisible(bool visible);
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
 private:
     void initUI();
 
-private:
+protected:
     QFrame *m_centerTopFrame;
     QFrame *m_centerFrame;
     QFrame *m_bottomFrame;
-    QVBoxLayout *m_mainLayou;
+    QVBoxLayout *m_mainLayout;
     QHBoxLayout *m_centerTopLayout;
     QHBoxLayout *m_centerLayout;
+    QVBoxLayout *m_centerVLayout;
     QHBoxLayout *m_leftBottomLayout;
     QHBoxLayout *m_centerBottomLayout;
     QHBoxLayout *m_rightBottomLayout;
     QWidget *m_centerTopWidget;
-    QWidget *m_centerWidget;
+    QPointer<QWidget> m_centerWidget;
     QWidget *m_leftBottomWidget;
     QWidget *m_centerBottomWidget;
     QWidget *m_rightBottomWidget;
+    QSpacerItem *m_centerSpacerItem;
 };
 
 #endif // SESSIONBASEWINDOW_H
