@@ -57,6 +57,7 @@ ShutdownWidget::ShutdownWidget(QWidget *parent)
     connect(this, &ShutdownWidget::destroyed, this, [ = ] {
         m_frameDataBind->unRegisterFunction("ShutdownWidget", index);
     });
+    installEventFilter(this);
 }
 
 ShutdownWidget::~ShutdownWidget()
@@ -70,43 +71,43 @@ void ShutdownWidget::initConnect()
 {
     connect(m_requireRestartButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireRestartButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireRestart);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireRestart, false);
     });
     connect(m_requireShutdownButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireShutdownButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown, false);
     });
     connect(m_requireSuspendButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireSuspendButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSuspend);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSuspend, false);
     });
     connect(m_requireHibernateButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireHibernateButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireHibernate);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireHibernate, false);
     });
     connect(m_requireLockButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireLockButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLock);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLock, false);
     });
     connect(m_requireSwitchUserBtn, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireSwitchUserBtn;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchUser);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchUser, false);
     });
     if (m_requireSwitchSystemBtn) {
         connect(m_requireSwitchSystemBtn, &RoundItemButton::clicked, this, [ = ] {
             m_currentSelectedBtn = m_requireSwitchSystemBtn;
-            onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchSystem);
+            onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchSystem, false);
         });
     }
     connect(m_requireLogoutButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireLogoutButton;
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLogout);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLogout, false);
     });
 
     connect(GSettingWatcher::instance(), &GSettingWatcher::enableChanged, this, &ShutdownWidget::onEnable);
 
     if (m_systemMonitor) {
-        connect(m_systemMonitor, &SystemMonitor::clicked, this, &ShutdownWidget::runSystemMonitor);
+        connect(m_systemMonitor, &SystemMonitor::requestShowSystemMonitor, this, &ShutdownWidget::runSystemMonitor);
     }
 }
 
@@ -171,21 +172,21 @@ void ShutdownWidget::enterKeyPushed()
         return;
 
     if (m_currentSelectedBtn == m_requireShutdownButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown, false);
     else if (m_currentSelectedBtn == m_requireRestartButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireRestart);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireRestart, false);
     else if (m_currentSelectedBtn == m_requireSuspendButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSuspend);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSuspend, false);
     else if (m_currentSelectedBtn == m_requireHibernateButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireHibernate);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireHibernate, false);
     else if (m_currentSelectedBtn == m_requireLockButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLock);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLock, false);
     else if (m_currentSelectedBtn == m_requireSwitchUserBtn)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchUser);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchUser, false);
     else if (m_currentSelectedBtn == m_requireSwitchSystemBtn)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchSystem);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireSwitchSystem, false);
     else if (m_currentSelectedBtn == m_requireLogoutButton)
-        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLogout);
+        onRequirePowerAction(SessionBaseModel::PowerAction::RequireLogout, false);
 }
 
 void ShutdownWidget::enableHibernateBtn(bool enable)
@@ -204,6 +205,7 @@ void ShutdownWidget::initUI()
     m_requireShutdownButton = new RoundItemButton(this);
     m_requireShutdownButton->setFocusPolicy(Qt::NoFocus);
     m_requireShutdownButton->setObjectName("RequireShutDownButton");
+    m_requireShutdownButton->setAccessibleName("RequireShutDownButton");
     m_requireShutdownButton->setAutoExclusive(true);
     updateTr(m_requireShutdownButton, "Shut down");
     GSettingWatcher::instance()->bind("systemShutdown", m_requireShutdownButton);  // GSettings配置项
@@ -211,18 +213,21 @@ void ShutdownWidget::initUI()
     m_requireRestartButton = new RoundItemButton(tr("Reboot"), this);
     m_requireRestartButton->setFocusPolicy(Qt::NoFocus);
     m_requireRestartButton->setObjectName("RequireRestartButton");
+    m_requireRestartButton->setAccessibleName("RequireRestartButton");
     m_requireRestartButton->setAutoExclusive(true);
     updateTr(m_requireRestartButton, "Reboot");
 
     m_requireSuspendButton = new RoundItemButton(tr("Suspend"), this);
     m_requireSuspendButton->setFocusPolicy(Qt::NoFocus);
     m_requireSuspendButton->setObjectName("RequireSuspendButton");
+    m_requireSuspendButton->setAccessibleName("RequireSuspendButton");
     m_requireSuspendButton->setAutoExclusive(true);
     updateTr(m_requireSuspendButton, "Suspend");
     GSettingWatcher::instance()->bind("systemSuspend", m_requireSuspendButton);  // GSettings配置项
 
     m_requireHibernateButton = new RoundItemButton(tr("Hibernate"), this);
     m_requireHibernateButton->setFocusPolicy(Qt::NoFocus);
+    m_requireHibernateButton->setAccessibleName("RequireHibernateButton");
     m_requireHibernateButton->setObjectName("RequireHibernateButton");
     m_requireHibernateButton->setAutoExclusive(true);
     updateTr(m_requireHibernateButton, "Hibernate");
@@ -230,6 +235,7 @@ void ShutdownWidget::initUI()
 
     m_requireLockButton = new RoundItemButton(tr("Lock"));
     m_requireLockButton->setFocusPolicy(Qt::NoFocus);
+    m_requireLockButton->setAccessibleName("RequireLockButton");
     m_requireLockButton->setObjectName("RequireLockButton");
     m_requireLockButton->setAutoExclusive(true);
     updateTr(m_requireLockButton, "Lock");
@@ -237,12 +243,14 @@ void ShutdownWidget::initUI()
 
     m_requireLogoutButton = new RoundItemButton(tr("Log out"));
     m_requireLogoutButton->setFocusPolicy(Qt::NoFocus);
+    m_requireLogoutButton->setAccessibleName("RequireLogoutButton");
     m_requireLogoutButton->setObjectName("RequireLogoutButton");
     m_requireLogoutButton->setAutoExclusive(true);
     updateTr(m_requireLogoutButton, "Log out");
 
     m_requireSwitchUserBtn = new RoundItemButton(tr("Switch user"));
     m_requireSwitchUserBtn->setFocusPolicy(Qt::NoFocus);
+    m_requireSwitchUserBtn->setAccessibleName("RequireSwitchUserButton");
     m_requireSwitchUserBtn->setObjectName("RequireSwitchUserButton");
     m_requireSwitchUserBtn->setAutoExclusive(true);
     updateTr(m_requireSwitchUserBtn, "Switch user");
@@ -250,6 +258,7 @@ void ShutdownWidget::initUI()
 
     if (m_switchosInterface->isDualOsSwitchAvail()) {
         m_requireSwitchSystemBtn = new RoundItemButton(tr("Switch system"));
+        m_requireSwitchSystemBtn->setAccessibleName("SwitchSystemButton");
         m_requireSwitchSystemBtn->setFocusPolicy(Qt::NoFocus);
         m_requireSwitchSystemBtn->setObjectName("RequireSwitchSystemButton");
         m_requireSwitchSystemBtn->setAutoExclusive(true);
@@ -284,6 +293,7 @@ void ShutdownWidget::initUI()
     m_shutdownLayout->addStretch(0);
 
     m_shutdownFrame = new QFrame;
+    m_shutdownFrame->setAccessibleName("ShutdownFrame");
     m_shutdownFrame->setLayout(m_shutdownLayout);
 
     m_actionLayout = new QVBoxLayout;
@@ -298,6 +308,7 @@ void ShutdownWidget::initUI()
         QFile file("/usr/bin/deepin-system-monitor");
         if (file.exists()) {
             m_systemMonitor = new SystemMonitor;
+            m_systemMonitor->setAccessibleName("SystemMonitor");
             m_systemMonitor->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
             m_systemMonitor->setFocusPolicy(Qt::NoFocus);
             setFocusPolicy(Qt::StrongFocus);
@@ -307,6 +318,7 @@ void ShutdownWidget::initUI()
     }
 
     m_actionFrame = new QFrame;
+    m_actionFrame->setAccessibleName("ActionFrame");
     m_actionFrame->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
     m_actionFrame->setFocusPolicy(Qt::NoFocus);
     m_actionFrame->setLayout(m_actionLayout);
@@ -348,6 +360,10 @@ void ShutdownWidget::leftKeySwitch()
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 
     m_frameDataBind->updateValue("ShutdownWidget", m_index);
+
+    if (m_systemMonitor && m_systemMonitor->isVisible()) {
+        m_systemMonitor->setState(SystemMonitor::Leave);
+    }
 }
 
 void ShutdownWidget::rightKeySwitch()
@@ -373,14 +389,17 @@ void ShutdownWidget::rightKeySwitch()
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 
     m_frameDataBind->updateValue("ShutdownWidget", m_index);
+
+    if (m_systemMonitor && m_systemMonitor->isVisible()) {
+        m_systemMonitor->setState(SystemMonitor::Leave);
+    }
 }
 
 void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
 {
-    //根据当前是锁屏还是关机,设置按钮可见状态,同时需要判官切换用户按钮是否允许可见
-    RoundItemButton * roundItemButton = m_requireShutdownButton;
+    RoundItemButton *roundItemButton;
     if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
-        m_requireLockButton->setVisible(true && (GSettingWatcher::instance()->getStatus("systemLock") != "Hiden"));
+        m_requireLockButton->setVisible(GSettingWatcher::instance()->getStatus("systemLock") != "Hiden");
         m_requireSwitchUserBtn->setVisible(m_switchUserEnable);
         if (m_requireSwitchSystemBtn) {
             m_requireSwitchSystemBtn->setVisible(true);
@@ -424,8 +443,8 @@ void ShutdownWidget::recoveryLayout()
     //同时需要判断切换用户按钮是否允许可见
     m_requireShutdownButton->setVisible(true && (GSettingWatcher::instance()->getStatus("systemShutdown") != "Hiden"));
     m_requireRestartButton->setVisible(true);
-    enableHibernateBtn(m_model->canSleep());
-    enableSleepBtn(m_model->hasSwap());
+    enableHibernateBtn(m_model->hasSwap());
+    enableSleepBtn(m_model->canSleep());
     m_requireLockButton->setVisible(true && (GSettingWatcher::instance()->getStatus("systemLock") != "Hiden"));
     m_requireSwitchUserBtn->setVisible(m_switchUserEnable);
 
@@ -437,11 +456,10 @@ void ShutdownWidget::recoveryLayout()
     setFocusPolicy(Qt::StrongFocus);
 }
 
-void ShutdownWidget::onRequirePowerAction(SessionBaseModel::PowerAction powerAction)
+void ShutdownWidget::onRequirePowerAction(SessionBaseModel::PowerAction powerAction, bool needConfirm)
 {
     //锁屏或关机模式时，需要确认是否关机或检查是否有阻止关机
-    if (m_model->currentType() == SessionBaseModel::AuthType::LockType ||
-        m_model->currentType() == SessionBaseModel::AuthType::UnknowAuthType) {
+    if (m_model->appType() == Lock) {
         switch (powerAction) {
         case SessionBaseModel::PowerAction::RequireShutdown:
         case SessionBaseModel::PowerAction::RequireRestart:
@@ -450,7 +468,7 @@ void ShutdownWidget::onRequirePowerAction(SessionBaseModel::PowerAction powerAct
         case SessionBaseModel::PowerAction::RequireSuspend:
         case SessionBaseModel::PowerAction::RequireHibernate:
             m_model->setIsCheckedInhibit(false);
-            emit m_model->shutdownInhibit(powerAction);
+            emit m_model->shutdownInhibit(powerAction, needConfirm);
             break;
         default:
             m_model->setPowerAction(powerAction);
@@ -473,6 +491,27 @@ void ShutdownWidget::setUserSwitchEnable(bool enable)
     m_requireSwitchUserBtn->setVisible(m_switchUserEnable && m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode);
 }
 
+bool ShutdownWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    Q_UNUSED(watched)
+    if (event->type() == QEvent::KeyPress) {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        if (keyEvent->key() == Qt::Key_Tab) {
+            if (m_systemMonitor && m_systemMonitor->isVisible() && m_currentSelectedBtn && m_currentSelectedBtn->isVisible()) {
+                if (m_currentSelectedBtn->isChecked()) {
+                    m_currentSelectedBtn->setChecked(false);
+                    m_systemMonitor->setState(SystemMonitor::Enter);
+                } else {
+                    m_currentSelectedBtn->setChecked(true);
+                    m_systemMonitor->setState(SystemMonitor::Leave);
+                }
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
 void ShutdownWidget::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
@@ -486,29 +525,16 @@ void ShutdownWidget::keyPressEvent(QKeyEvent *event)
     case Qt::Key_Return:
         enterKeyPushed();
         break;
-    case Qt::Key_Tab: {
-        if (m_systemMonitor && m_currentSelectedBtn->isVisible() && m_systemMonitor->isVisible()) {
-            if (m_currentSelectedBtn && m_currentSelectedBtn->isChecked()) {
-                m_currentSelectedBtn->setChecked(false);
-                m_systemMonitor->setState(SystemMonitor::Enter);
-            } else if (m_systemMonitor->state() == SystemMonitor::Enter) {
-                m_systemMonitor->setState(SystemMonitor::Leave);
-                m_currentSelectedBtn->setChecked(true);
-            }
-        }
-        break;
-    }
     default:
         break;
     }
 
-    QFrame::keyReleaseEvent(event);
+    QFrame::keyPressEvent(event);
 }
 
 bool ShutdownWidget::event(QEvent *e)
 {
     if (e->type() == QEvent::LanguageChange) {
-        // refresh language
         for (auto it = m_trList.constBegin(); it != m_trList.constEnd(); ++it) {
             it->first(qApp->translate("ShutdownWidget", it->second.toUtf8()));
         }
@@ -519,6 +545,9 @@ bool ShutdownWidget::event(QEvent *e)
             m_index = 0;
         }
         m_frameDataBind->updateValue("ShutdownWidget", m_index);
+        m_btnList.at(m_index)->updateState(RoundItemButton::Checked);
+    } else if (e->type() == QEvent::FocusOut) {
+        m_btnList.at(m_index)->updateState(RoundItemButton::Normal);
     }
 
     return QFrame::event(e);
@@ -530,6 +559,17 @@ void ShutdownWidget::showEvent(QShowEvent *event)
     QFrame::showEvent(event);
 }
 
+void ShutdownWidget::updateLocale(std::shared_ptr<User> user)
+{
+    //只有登陆界面才需要根据系统切换语言
+    if(qApp->applicationName() == "dde-lock") return;
+
+    // refresh language
+    for (auto it = m_trList.constBegin(); it != m_trList.constEnd(); ++it) {
+        it->first(qApp->translate("ShutdownWidget", it->second.toUtf8()));
+    }
+}
+
 void ShutdownWidget::setModel(SessionBaseModel *const model)
 {
     m_model = model;
@@ -540,5 +580,7 @@ void ShutdownWidget::setModel(SessionBaseModel *const model)
     enableHibernateBtn(model->hasSwap());
 
     connect(model, &SessionBaseModel::canSleepChanged, this, &ShutdownWidget::enableSleepBtn);
+    connect(model, &SessionBaseModel::currentUserChanged, this, &ShutdownWidget::updateLocale);
+
     enableSleepBtn(model->canSleep());
 }
