@@ -88,6 +88,9 @@ QList<InhibitWarnView::InhibitorData> WarningContent::listInhibitors(const Sessi
                     inhibitData.mode = inhibitor.mode;
                     inhibitData.pid = inhibitor.pid;
 
+                    if(action == SessionBaseModel::PowerAction::RequireLogout && inhibitor.uid != m_model->currentUser()->uid())
+                        continue;
+
                     // 读取翻译后的文本，读取应用图标
                     QDBusConnection connection = QDBusConnection::sessionBus();
                     if (!inhibitor.uid) {
@@ -97,7 +100,7 @@ QList<InhibitWarnView::InhibitorData> WarningContent::listInhibitors(const Sessi
                     if (connection.interface()->isServiceRegistered(inhibitor.who)) {
 
                         QDBusInterface ifc(inhibitor.who, "/com/deepin/InhibitHint", "com.deepin.InhibitHint", connection);
-                        QDBusMessage msg = ifc.call("Get", getenv("LANG"), inhibitor.why);
+                        QDBusMessage msg = ifc.call("Get", qgetenv("LANG"), inhibitor.why);
                         if (msg.type() == QDBusMessage::ReplyMessage) {
                             InhibitHint inhibitHint = qdbus_cast<InhibitHint>(msg.arguments().at(0).value<QDBusArgument>());
 
@@ -147,14 +150,19 @@ void WarningContent::doAccecpShutdownInhibit()
 
     m_model->setIsCheckedInhibit(true);
     m_model->setPowerAction(m_powerAction);
-    emit m_model->cancelShutdownInhibit();
+    if (m_model->currentModeState() != SessionBaseModel::ModeStatus::ShutDownMode)
+        emit m_model->cancelShutdownInhibit();
 }
 
-void WarningContent::beforeInvokeAction()
+void WarningContent::beforeInvokeAction(bool needConfirm)
 {
-    WarningView * old_warningView = m_warningView;
     const QList<InhibitWarnView::InhibitorData> inhibitors = listInhibitors(m_powerAction);
-    const QList<std::shared_ptr<User>> &loginUsers = m_model->logindUser();
+    const QList<std::shared_ptr<User>> &loginUsers = m_model->loginedUserList();
+
+    if (m_warningView != nullptr) {
+        m_warningView->deleteLater();
+        m_warningView = nullptr;
+    }
 
     // change ui
     if (!inhibitors.isEmpty()) {
@@ -218,11 +226,6 @@ void WarningContent::beforeInvokeAction()
         m_warningView->setFixedSize(getCenterContentSize());
         setCenterContent(m_warningView);
 
-        if (old_warningView) {
-            old_warningView->deleteLater();
-        }
-        old_warningView = m_warningView;
-
         connect(view, &InhibitWarnView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
         connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
 
@@ -253,18 +256,15 @@ void WarningContent::beforeInvokeAction()
         m_warningView->setFixedSize(getCenterContentSize());
         setCenterContent(m_warningView);
 
-        if (old_warningView) {
-            old_warningView->deleteLater();
-        }
-        old_warningView = m_warningView;
-
         connect(view, &MultiUsersWarningView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
         connect(view, &MultiUsersWarningView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
 
         return;
     }
 
-    if (m_powerAction == SessionBaseModel::PowerAction::RequireShutdown || m_powerAction == SessionBaseModel::PowerAction::RequireRestart || m_powerAction == SessionBaseModel::PowerAction::RequireLogout) {
+    if (needConfirm && (m_powerAction == SessionBaseModel::PowerAction::RequireShutdown ||
+                        m_powerAction == SessionBaseModel::PowerAction::RequireRestart ||
+                        m_powerAction == SessionBaseModel::PowerAction::RequireLogout)) {
         InhibitWarnView *view = new InhibitWarnView(m_powerAction, this);
         view->setFocusPolicy(Qt::StrongFocus);
         setFocusPolicy(Qt::NoFocus);
@@ -283,11 +283,6 @@ void WarningContent::beforeInvokeAction()
         m_warningView->setFixedSize(getCenterContentSize());
         setCenterContent(m_warningView);
 
-        if (old_warningView) {
-            old_warningView->deleteLater();
-        }
-        old_warningView = m_warningView;
-
         connect(view, &InhibitWarnView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
         connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
 
@@ -297,6 +292,13 @@ void WarningContent::beforeInvokeAction()
     doAccecpShutdownInhibit();
 }
 
+void WarningContent::setPowerAction(const SessionBaseModel::PowerAction action)
+{
+    if (m_powerAction == action)
+        return;
+    m_powerAction = action;
+}
+
 void WarningContent::mouseReleaseEvent(QMouseEvent *event)
 {
     doCancelShutdownInhibit();
