@@ -1,124 +1,278 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
-    <name>ContentWidget</name>
+    <name>AuthFace</name>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
-        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
-        <translation>Els programes eviten que l’ordinador s&apos;aturi i forçar-ho pot causar pèrdues de dades.</translation>
+        <source>Face ID</source>
+        <translation>Identificació facial</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
-        <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>Per tancar el programa, cliqueu a Cancel·la i, a continuació, tanqueu el programa.</translation>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
-        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
-        <translation>Els programes eviten que l’ordinador es reiniciï i forçar-ho pot causar pèrdues de dades.</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
-        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
-        <translation>Els programes eviten que l’ordinador es posi en suspensió i forçar-ho pot causar pèrdues de dades.</translation>
+        <source>Verify your Face ID</source>
+        <translation>Verifica la identificació facial</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
-        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
-        <translation>Els programes eviten que l’ordinador hiberni i forçar-ho pot causar pèrdues de dades.</translation>
+        <source>Face ID locked, use password please</source>
+        <translation>Identificació facial blocada. Useu la contrasenya.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthFingerprint</name>
+    <message>
+        <source>Verify your fingerprint</source>
+        <translation>Verifiqueu l&apos;empremta</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
-        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
-        <translation>Els programes eviten que l’ordinador surti de la sessió i forçar-ho pot causar pèrdues de dades.</translation>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
-        <source>Shut down</source>
-        <translation>Atura&apos;t</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
-        <source>Reboot</source>
-        <translation>Reinicia</translation>
+        <source>Fingerprint locked, use password please</source>
+        <translation>Empremta blocada. Si us plau, useu la contrasenya.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
-        <source>Suspend</source>
-        <translation>Suspèn</translation>
+        <source>Please try again 1 minute later</source>
+        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
+    </message>
+</context>
+<context>
+    <name>AuthIris</name>
+    <message>
+        <source>Iris ID</source>
+        <translation>ID d&apos;iris</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
-        <source>Hibernate</source>
-        <translation>Hiberna</translation>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
-        <source>Log out</source>
-        <translation>Surt de la sessió</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
-        <source>Are you sure you want to shut down?</source>
-        <translation>Segur que voleu que m&apos;aturi?</translation>
+        <source>Verify your Iris ID</source>
+        <translation>Verifica la identificació d&apos;iris</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
-        <source>Are you sure you want to reboot?</source>
-        <translation>Segur que voleu reiniciar-me?</translation>
+        <source>Iris ID locked, use password please</source>
+        <translation>Identificació d&apos;iris blocada. Useu la contrasenya.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthPassword</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
-        <source>Are you sure you want to log out?</source>
-        <translation>Segur que voleu sortir de la sessió?</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
-        <source>Lock</source>
-        <translation>Bloca</translation>
+        <source>Wrong Password</source>
+        <translation>Contrasenya incorrecta</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
-        <source>Switch user</source>
-        <translation>Canvia d&apos;usuari</translation>
+        <source>Password</source>
+        <translation>Contrasenya</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
-        <source>Switch system</source>
-        <translation>Canvia de sistema</translation>
+        <source>Please try again 1 minute later</source>
+        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>Restableix la contrasenya</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>Heu oblidat la contrasenya?</translation>
+    </message>
+</context>
+<context>
+    <name>AuthSingle</name>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>Restableix la contrasenya</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>Heu oblidat la contrasenya?</translation>
+    </message>
+</context>
+<context>
+    <name>AuthUKey</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>PIN incorrecte</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>Cal la clau</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>Marqueu el PIN</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthWidget</name>
+    <message>
+        <source>Account</source>
+        <translation>Compte</translation>
+    </message>
+    <message numerus="yes">
+        <source>Your password will expire in %n days, please change it timely</source>
+        <translation><numerusform>La contrasenya caducarà d&apos;aquí a %d dia; canvieu-la oportunament.</numerusform><numerusform>La contrasenya caducarà d&apos;aquí a %d dies; canvieu-la oportunament.</numerusform></translation>
+    </message>
+    <message>
+        <source>Password expired, please change</source>
+        <translation>La contrasenya ha caducat. Si us plau, canvieu-la.</translation>
+    </message>
+</context>
+<context>
+    <name>AuthenticationModule</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Verificació correcta</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Ha fallat la verificació. Només resta un intent.</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>Contrasenya incorrecta</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>PIN incorrecte</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>Cal la clau</translation>
+    </message>
+    <message>
+        <source>Verify your fingerprint</source>
+        <translation>Verifiqueu l&apos;empremta</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Contrasenya</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>Marqueu el PIN</translation>
+    </message>
+    <message>
+        <source>Fingerprint locked, use password please</source>
+        <translation>Empremta blocada. Si us plau, useu la contrasenya.</translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
     </message>
 </context>
 <context>
     <name>GreeterWorkek</name>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
-        <source>Wrong Password</source>
-        <translation>Contrasenya incorrecta</translation>
+        <source>Wrong account</source>
+        <translation>Compte incorrecte</translation>
     </message>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
-        <source>The account or password is not correct. Please enter again.</source>
-        <translation>El compte o la contrasenya no són correctes. Si us plau, torneu-hi.</translation>
+        <source>Wrong Password</source>
+        <translation>Contrasenya incorrecta</translation>
     </message>
 </context>
 <context>
     <name>InhibitWarnView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
-        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
@@ -126,12 +280,10 @@
 <context>
     <name>LockContent</name>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
         <source>Lock Screen</source>
         <translation>Pantalla de bloqueig</translation>
     </message>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
         <source>Failed to lock screen</source>
         <translation>Ha fallat blocar la pantalla.</translation>
     </message>
@@ -139,84 +291,67 @@
 <context>
     <name>LockWorker</name>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
         <source>Fingerprint verification timed out, please enter your password manually</source>
         <translation>S&apos;ha acabat el temps d&apos;espera de la verificació de l&apos;empremta. Si us plau, escriviu la contrasenya manualment.</translation>
     </message>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
         <source>Failed to match fingerprint</source>
         <translation>Ha fallat la coincidència de contrasenyes.</translation>
     </message>
-    <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
-        <source>Wrong Password</source>
-        <translation>Contrasenya incorrecta</translation>
-    </message>
 </context>
 <context>
     <name>MultiUsersWarningView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
         <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa de l&apos;aturada. Segur que voleu que m&apos;aturi?</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
         <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa del reinici. Segur que voleu que em reiniciï?</translation>
     </message>
 </context>
+<context>
+    <name>SessionWidget</name>
+    <message>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ShutdownWidget</name>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
         <source>Shut down</source>
         <translation>Atura&apos;t</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
         <source>Reboot</source>
         <translation>Reinicia</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
         <source>Suspend</source>
         <translation>Suspèn</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
         <source>Hibernate</source>
         <translation>Hiberna</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
         <source>Lock</source>
         <translation>Bloqueja</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
         <source>Log out</source>
         <translation>Surt de la sessió</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
         <source>Switch user</source>
         <translation>Canvia d&apos;usuari</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
         <source>Switch system</source>
         <translation>Canvia de sistema</translation>
     </message>
@@ -224,8 +359,6 @@
 <context>
     <name>SystemMonitor</name>
     <message>
-        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
-        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
         <source>Start system monitor</source>
         <translation>Inicia el monitor del sistema</translation>
     </message>
@@ -233,111 +366,86 @@
 <context>
     <name>UserLoginWidget</name>
     <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
-        <source>Password</source>
-        <translation>Contrasenya</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
         <source>Account</source>
         <translation>Compte</translation>
     </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
-        <source>Please enter the account</source>
-        <translation>Si us plau, introduïu el compte.</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
-        <source>Please enter the password</source>
-        <translation>Si us plau, escriviu la contrasenya.</translation>
-    </message>
     <message numerus="yes">
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
+        <source>Your password will expire in %n days, please change it timely</source>
+        <translation><numerusform>La contrasenya caducarà d&apos;aquí a %d dia; canvieu-la oportunament.</numerusform><numerusform>La contrasenya caducarà d&apos;aquí a %d dies; canvieu-la oportunament.</numerusform></translation>
+    </message>
+    <message>
+        <source>Password expired, please change</source>
+        <translation>La contrasenya ha caducat. Si us plau, canvieu-la.</translation>
     </message>
 </context>
 <context>
     <name>WarningContent</name>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
         <translation>Els programes eviten que l’ordinador s&apos;aturi i forçar-ho pot causar pèrdues de dades.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
         <source>To close the program, click Cancel, and then close the program.</source>
         <translation>Per tancar el programa, cliqueu a Cancel·la i, a continuació, tanqueu el programa.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
         <translation>Els programes eviten que l’ordinador es reiniciï i forçar-ho pot causar pèrdues de dades.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
         <translation>Els programes eviten que l’ordinador es posi en suspensió i forçar-ho pot causar pèrdues de dades.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
         <translation>Els programes eviten que l’ordinador hiberni i forçar-ho pot causar pèrdues de dades.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
         <translation>Els programes eviten que l’ordinador surti de la sessió i forçar-ho pot causar pèrdues de dades.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
         <source>Shut down</source>
         <translation>Atura&apos;t</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
         <source>Reboot</source>
         <translation>Reinicia</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
         <source>Suspend</source>
         <translation>Suspèn</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
         <source>Hibernate</source>
         <translation>Hiberna</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
         <source>Log out</source>
         <translation>Tanca la sessió</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
         <source>Are you sure you want to shut down?</source>
         <translation>Segur que voleu que m&apos;aturi?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
         <source>Are you sure you want to reboot?</source>
         <translation>Segur que voleu que em reiniciï?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
         <source>Are you sure you want to log out?</source>
         <translation>Segur que voleu sortir de la sessió?</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Turn on</source>
+        <translation>Activa</translation>
+    </message>
+    <message>
+        <source>Turn off</source>
+        <translation>Desactiva</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
