@@ -1,124 +1,227 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
 <context>
-    <name>ContentWidget</name>
+    <name>AuthFace</name>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
-        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
-        <translation>يۇقارقى پىروگراممىلار تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن</translation>
+        <source>Face ID</source>
+        <translation>چىراي قۇلۇپى</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
-        <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>«بىكار قىلىش»نى چېكىپ بۇ پىروگراممىلارنى تاقىۋەتسىڭىز بولىدۇ.</translation>
+        <source>Verification successful</source>
+        <translation>دەلىللەندى</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
-        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
-        <translation>يۇقارقى پىروگراممىلار قايتا قوزغىتىشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا قوزغاتسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
-        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
-        <translation>يۇقارقى پىروگراممىلار ۋاقىتلىق تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ۋاقىتلىق تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
+        <source>Verify your Face ID</source>
+        <translation>چىراي قۇلۇپىڭىزنى دەلىللەڭ</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
-        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
-        <translation>يۇقارقى پىروگراممىلارئۇخلاش ھالىتىگە كىرىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ئۇخلاش ھالىتىگە كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
+        <source>Face ID locked, use password please</source>
+        <translation>چىرايدا قۇلۇپ ئېچىش قۇلۇپلىنىپ قالدى، پارولنى كىرگۈزۈپ ئېچىڭ</translation>
     </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
-        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
-        <translation>يۇقارقى پىروگراممىلار قايتا كىرىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
-        <source>Shut down</source>
-        <translation>تاقاش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
-        <source>Reboot</source>
-        <translation>قايتا قوزغىتىش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
-        <source>Suspend</source>
-        <translation>ئېسىپ قويۇش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
-        <source>Hibernate</source>
-        <translation>ئۇخلاش ھالىتى</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
-        <source>Log out</source>
-        <translation>تىزىمدىن چېكىنىش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
-        <source>Are you sure you want to shut down?</source>
-        <translation>راستلا تاقامسىز؟</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
-        <source>Are you sure you want to reboot?</source>
-        <translation>راستلا قايتا قوزغىتامسىز؟</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
-        <source>Are you sure you want to log out?</source>
-        <translation>راستلا قايتا كىرەمسىز؟</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
-        <source>Lock</source>
-        <translation>قۇلۇپلاش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
-        <source>Switch user</source>
-        <translation>ئىشلەتكۈچى ئالمىشىش</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
-        <source>Switch system</source>
-        <translation>سىستېما ئالماشتۇرۇش</translation>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>يەنە %n% مىنۇتتىن كېيىن قايتا سىناڭ </numerusform></translation>
     </message>
 </context>
 <context>
-    <name>GreeterWorkek</name>
+    <name>AuthFingerprint</name>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
-        <source>Wrong Password</source>
-        <translation>ئىناۋەتسىز پارول</translation>
+        <source>Verify your fingerprint</source>
+        <translation>بارماق ئىزى ئارقىلىق دەلىللەڭ</translation>
     </message>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
-        <source>The account or password is not correct. Please enter again.</source>
-        <translation>ھېساباتىڭىز ياكى شىفىر توغرا ئەمەس، قايتا كىرگۈزۈڭ.</translation>
+        <source>Verification successful</source>
+        <translation>دەلىللەندى</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
+    </message>
+    <message>
+        <source>Fingerprint locked, use password please</source>
+        <translation>بارماق ئىزى قۇلۇپلاندى، پارول كىرگۈزۈڭ</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
+    </message>
+</context>
+<context>
+    <name>AuthIris</name>
+    <message>
+        <source>Iris ID</source>
+        <translation>كۆز رەڭدار پەردىسى قۇلۇپى</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>دەلىللەندى</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
+    </message>
+    <message>
+        <source>Verify your Iris ID</source>
+        <translation>كۆز رەڭدار پەردىڭىزنى دەلىللەڭ</translation>
+    </message>
+    <message>
+        <source>Iris ID locked, use password please</source>
+        <translation> كۆز رەڭدار پەردىسىنى تونۇپ قۇلۇپنى ئېچىش مەغلۇپ بولدى ، پارولنى كىرگۈزۈڭ </translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>يەنە %n% مىنۇتتىن كېيىن قايتا سىناڭ </numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthPassword</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>دەلىللەندى</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>پارول خاتا</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>پارول</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>قايتا پارول تەكشەش</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>پارول  قايتۇرۇش </translation>
+    </message>
+</context>
+<context>
+    <name>AuthSingle</name>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>قايتا پارول تەكشەش</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>پارول  قايتۇرۇش </translation>
+    </message>
+</context>
+<context>
+    <name>AuthUKey</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>دەلىللەندى</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform><numerusform>دەلىللەش مەغلۇپ بولدى، يەنە %n قېتىم سىنىيالايسىز</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>دەلىللەش مەغلۇپ بولدى، يەنە 1 قېتىم سىنىيالايسىز</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>PIN خاتا</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>UKEY ئارقىلىق دەلىللەش كېرەك</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>UKEY بايقالدى، PINنى كىرگۈزۈڭ</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>1 مىنۇتتىن كېيىن قايتا سىناڭ</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>يەنە %n% مىنۇتتىن كېيىن قايتا سىناڭ </numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthWidget</name>
+    <message>
+        <source>Account</source>
+        <translation>ھېسابات</translation>
+    </message>
+    <message numerus="yes">
+        <source>Your password will expire in %n days, please change it timely</source>
+        <translation><numerusform>پارولنىڭ ۋاقتى %n كۈندە توشىدۇ، پارولنى ۋاقتىدا ئۆزگەرتىڭ</numerusform><numerusform>پارولنىڭ ۋاقتى %n كۈندە توشىدۇ، پارولنى ۋاقتىدا ئۆزگەرتىڭ</numerusform></translation>
+    </message>
+    <message>
+        <source>Password expired, please change</source>
+        <translation>پارولنىڭ ۋاقتى ئۆتتى، ئۆزگەرتىڭ</translation>
+    </message>
+</context>
+<context>
+    <name>GreeterWorker</name>
+    <message>
+        <source>Wrong account</source>
+        <translation>ھېسابات نومۇرى خاتا</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>پارول خاتا</translation>
     </message>
 </context>
 <context>
     <name>InhibitWarnView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
-        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
         <source>Cancel</source>
         <translation>بىكار قىلىش</translation>
     </message>
@@ -126,12 +229,10 @@
 <context>
     <name>LockContent</name>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
         <source>Lock Screen</source>
         <translation>ئېكران قۇلۇپى</translation>
     </message>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
         <source>Failed to lock screen</source>
         <translation>ئېكراننى قۇلۇپلانمىدى</translation>
     </message>
@@ -139,84 +240,67 @@
 <context>
     <name>LockWorker</name>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
         <source>Fingerprint verification timed out, please enter your password manually</source>
         <translation>بارماق پارولىنى دەلىللەش ۋاقتى ئۆتۈپ كەتتى، پارول كىرگۈزۈڭ</translation>
     </message>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
         <source>Failed to match fingerprint</source>
         <translation>ئېكراننى بارماق ئېزى ئارقىلىق ئېچىش مەغلۇپ بولدى</translation>
     </message>
-    <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
-        <source>Wrong Password</source>
-        <translation>ئىناۋەتسىز پارول</translation>
-    </message>
 </context>
 <context>
     <name>MultiUsersWarningView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
         <source>Cancel</source>
         <translation>بىكار قىلىش</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
         <translation>بۇ كومپيۇتېردا يەنە يۇقارقى ھېساباتلار ئوچۇق، تاقىۋەتسىڭىز سانلىق مەلۇماتلار يوقاپ كېتىشى مۇمكىن، راستلا تاقامسىز؟</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
         <translation>بۇ كومپيۇتېردا يەنە يۇقارقى ھېساباتلار ئوچۇق، قايتا قوزغاتسىڭىز سانلىق مەلۇماتلار يوقاپ كېتىشى مۇمكىن، راستلا قايتا قوزغىتامسىز؟</translation>
     </message>
 </context>
+<context>
+    <name>SessionWidget</name>
+    <message>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation>يۇقىرى دەرىجىلىك قوغداشنى قوزغاتتىڭىز، Wayland ئەندىزىسىگە ئالماشتۇرغىلى بولمىدى، «بىخەتەرلىك مەركىزى»دىن يۇقىرى دەرىجىلىك قوغداشنى تاقىغاندىن كېيىن قايتا سىناڭ</translation>
+    </message>
+</context>
 <context>
     <name>ShutdownWidget</name>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
         <source>Shut down</source>
         <translation>تاقاش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
         <source>Reboot</source>
         <translation>قايتا قوزغىتىش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
         <source>Suspend</source>
         <translation>ئېسىپ قويۇش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
         <source>Hibernate</source>
         <translation>ئۇخلاش ھالىتى</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
         <source>Lock</source>
         <translation>قۇلۇپلاش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
         <source>Log out</source>
         <translation>چېكىنىش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
         <source>Switch user</source>
         <translation>ئىشلەتكۈچى ئالماشتۇرۇش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
         <source>Switch system</source>
         <translation>سىستېما ئالماشتۇرۇش</translation>
     </message>
@@ -224,120 +308,78 @@
 <context>
     <name>SystemMonitor</name>
     <message>
-        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
-        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
         <source>Start system monitor</source>
         <translation>سىستېما نازارەتچىسىنى قوزغىتىش</translation>
     </message>
 </context>
-<context>
-    <name>UserLoginWidget</name>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
-        <source>Password</source>
-        <translation>پارول</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
-        <source>Account</source>
-        <translation>ھېسابات</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
-        <source>Please enter the account</source>
-        <translation>ھېساباتىڭىزنى كىرگۈزۈڭ</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
-        <source>Please enter the password</source>
-        <translation>پارولىڭىزنى كىرگۈزۈڭ</translation>
-    </message>
-    <message numerus="yes">
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform><numerusform>%n مىنۇتتىن كېيىن قايتا سىناڭ</numerusform></translation>
-    </message>
-</context>
 <context>
     <name>WarningContent</name>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
         <translation>يۇقارقى پىروگراممىلار تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
         <source>To close the program, click Cancel, and then close the program.</source>
         <translation>«بىكار قىلىش»نى چېكىپ بۇ پىروگراممىلارنى تاقىۋەتسىڭىز بولىدۇ.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
         <translation>يۇقارقى پىروگراممىلار قايتا قوزغىتىشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا قوزغاتسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
         <translation>يۇقارقى پىروگراممىلار ۋاقىتلىق تاقاشقا توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ۋاقىتلىق تاقىسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
         <translation>يۇقارقى پىروگراممىلارئۇخلاش ھالىتىگە كىرىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي ئۇخلاش ھالىتىگە كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
         <translation>يۇقارقى پىروگراممىلار چېكىنىشكە توسقۇنلۇق قىلىۋاتىدۇ، مەجبۇرىي قايتا كىرسىڭىز سانلىق مەلۇماتلىرىڭىز يوقاپ كېتىشى مۇمكىن.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
         <source>Shut down</source>
         <translation>تاقاش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
         <source>Reboot</source>
         <translation>قايتا قوزغىتىش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
         <source>Suspend</source>
         <translation>ۋاقىتلىق تاقاش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
         <source>Hibernate</source>
         <translation>ئۇخلاش ھالىتى</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
         <source>Log out</source>
         <translation>چېكىنىش</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
         <source>Are you sure you want to shut down?</source>
         <translation>راستلا تاقامسىز؟</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
         <source>Are you sure you want to reboot?</source>
         <translation>راستلا قايتا قوزغىتامسىز؟</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
         <source>Are you sure you want to log out?</source>
         <translation>راستلا چېكىنەمسىز؟</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Turn on</source>
+        <translation>ئاچ</translation>
+    </message>
+    <message>
+        <source>Turn off</source>
+        <translation>تاقا</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
