@@ -1,124 +1,227 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
 <context>
-    <name>ContentWidget</name>
+    <name>AuthFace</name>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
-        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
-        <translation>Програми не дозволяють вимкнути комп&apos;ютер, а примусове вимкнення може призвести до втрати даних.</translation>
+        <source>Face ID</source>
+        <translation>Ідентифікація за обличчям</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
-        <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>Щоб завершити роботу програми, натисніть кнопку «Скасувати» і закрийте вікно програми.</translation>
+        <source>Verification successful</source>
+        <translation>Перевірку пройдено</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
-        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
-        <translation>Програми не дозволяють перезавантажити комп&apos;ютер, і примусове перезавантаження може призвести до втрати даних.</translation>
+        <source>Verification failed, only one chance left</source>
+        <translation>Перевірку не пройдено. Лишилася лише одна спроба.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
-        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
-        <translation>Програми не дозволяють призупинити роботу комп&apos;ютера, а примушування призупинення може призвести до втрати даних.</translation>
+        <source>Verify your Face ID</source>
+        <translation>Перевірте ваш ідентифікатор обличчя</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
-        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
-        <translation>Програми запобігають сплячому стану комп’ютера, а примушування до сплячого режиму може призвести до втрати даних.</translation>
+        <source>Face ID locked, use password please</source>
+        <translation>Ідентифікатор обличчя заблоковано. Скористайтеся, будь ласка, паролем</translation>
     </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
-        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
-        <translation>Програми перешкоджають виходу з комп&apos;ютера, а примусовий вихід може призвести до втрати даних.</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
-        <source>Shut down</source>
-        <translation>Вимкнути</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
-        <source>Reboot</source>
-        <translation>Перезавантажити</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
-        <source>Suspend</source>
-        <translation>Призупинити</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
-        <source>Hibernate</source>
-        <translation>Приспати</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
-        <source>Log out</source>
-        <translation>Вихід</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
-        <source>Are you sure you want to shut down?</source>
-        <translation>Ви впевнені, що хочете вимкнути компʼютер?</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
-        <source>Are you sure you want to reboot?</source>
-        <translation>Ви впевнені, що хочете перезавантажити?</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
-        <source>Are you sure you want to log out?</source>
-        <translation>Ви впевнені, що хочете вийти?</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
-        <source>Lock</source>
-        <translation>Заблокувати</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
-        <source>Switch user</source>
-        <translation>Змінити користувача</translation>
-    </message>
-    <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
-        <source>Switch system</source>
-        <translation>Перемкнути систему</translation>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
     </message>
 </context>
 <context>
-    <name>GreeterWorkek</name>
+    <name>AuthFingerprint</name>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
-        <source>Wrong Password</source>
-        <translation>Невірний Пароль</translation>
+        <source>Verify your fingerprint</source>
+        <translation>Перевірити ваш відбиток</translation>
     </message>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
-        <source>The account or password is not correct. Please enter again.</source>
-        <translation>Назва облікового запису або пароль є помилковими. Будь ласка, повторіть спробу їхнього введення.</translation>
+        <source>Verification successful</source>
+        <translation>Перевірку пройдено</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
+    </message>
+    <message>
+        <source>Fingerprint locked, use password please</source>
+        <translation>Відбиток заблоковано. Будь ласка, скористайтеся паролем.</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Будь ласка, повторіть спробу за хвилину</translation>
+    </message>
+</context>
+<context>
+    <name>AuthIris</name>
+    <message>
+        <source>Iris ID</source>
+        <translation>Ідентифікаціія за райдужкою</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>Перевірку пройдено</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Перевірку не пройдено. Лишилася лише одна спроба.</translation>
+    </message>
+    <message>
+        <source>Verify your Iris ID</source>
+        <translation>Перевірте ваш ідентифікатор райдужки</translation>
+    </message>
+    <message>
+        <source>Iris ID locked, use password please</source>
+        <translation>Ідентифікатор райдужки заблоковано. Скористайтеся, будь ласка, паролем</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthPassword</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Перевірку пройдено</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>Помилковий пароль</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Пароль</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Будь ласка, повторіть спробу за хвилину</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>Скинути пароль</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>Забули пароль?</translation>
+    </message>
+</context>
+<context>
+    <name>AuthSingle</name>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Будь ласка, повторіть спробу за хвилину</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+    <message>
+        <source>Reset Password</source>
+        <translation>Скинути пароль</translation>
+    </message>
+    <message>
+        <source>Forgot password?</source>
+        <translation>Забули пароль?</translation>
+    </message>
+</context>
+<context>
+    <name>AuthUKey</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Перевірку пройдено</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>Помилковий пін-код</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>Потрібен UKey</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>Введіть ваш пін-код</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Будь ласка, повторіть спробу за хвилину</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthWidget</name>
+    <message>
+        <source>Account</source>
+        <translation>Обліковий запис</translation>
+    </message>
+    <message numerus="yes">
+        <source>Your password will expire in %n days, please change it timely</source>
+        <translation><numerusform>Строк дії вашого пароля буде вичерпано за %n день. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n дні. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n днів. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n день. Будь ласка, вчасно змініть його</numerusform></translation>
+    </message>
+    <message>
+        <source>Password expired, please change</source>
+        <translation>Строк дії пароля вичерпано. Будь ласка, змініть</translation>
+    </message>
+</context>
+<context>
+    <name>GreeterWorker</name>
+    <message>
+        <source>Wrong account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>InhibitWarnView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
-        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
         <source>Cancel</source>
         <translation>Скасувати</translation>
     </message>
@@ -126,12 +229,10 @@
 <context>
     <name>LockContent</name>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
         <source>Lock Screen</source>
         <translation>Блокування екрана</translation>
     </message>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
         <source>Failed to lock screen</source>
         <translation>Не вдалося заблокувати екран</translation>
     </message>
@@ -139,84 +240,67 @@
 <context>
     <name>LockWorker</name>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
         <source>Fingerprint verification timed out, please enter your password manually</source>
         <translation>Не вдалося вчасно пройти розпізнавання за відбитком. Будь ласка, введіть ваш пароль вручну.</translation>
     </message>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
         <source>Failed to match fingerprint</source>
         <translation>Не вдалося порівняти відбиток</translation>
     </message>
-    <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
-        <source>Wrong Password</source>
-        <translation>Невірний Пароль</translation>
-    </message>
 </context>
 <context>
     <name>MultiUsersWarningView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
         <source>Cancel</source>
         <translation>Скасувати</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
         <translation>Вищевказані користувачі все ще знаходяться в системі, і їх дані будуть втрачені внаслідок вимкнення.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
         <translation>Вищевказані користувачі все ще знаходяться в системі, і їх дані будуть втрачені у випадку перезавантаження. Ви впевнені, що хочете перезавантажитись?</translation>
     </message>
 </context>
+<context>
+    <name>SessionWidget</name>
+    <message>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ShutdownWidget</name>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
         <source>Shut down</source>
         <translation>Вимкнути</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
         <source>Reboot</source>
         <translation>Перезавантажити</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
         <source>Suspend</source>
         <translation>Призупинити</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
         <source>Hibernate</source>
         <translation>Приспати</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
         <source>Lock</source>
         <translation>Заблокувати</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
         <source>Log out</source>
         <translation>Вихід</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
         <source>Switch user</source>
         <translation>Змінити користувача</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
         <source>Switch system</source>
         <translation>Перемкнути систему</translation>
     </message>
@@ -224,120 +308,78 @@
 <context>
     <name>SystemMonitor</name>
     <message>
-        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
-        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
         <source>Start system monitor</source>
         <translation>Запустити системний монітор</translation>
     </message>
 </context>
-<context>
-    <name>UserLoginWidget</name>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
-        <source>Password</source>
-        <translation>Пароль</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
-        <source>Account</source>
-        <translation>Обліковий запис</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
-        <source>Please enter the account</source>
-        <translation>Будь ласка, вкажіть обліковий запис</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
-        <source>Please enter the password</source>
-        <translation>Будь ласка, введіть пароль</translation>
-    </message>
-    <message numerus="yes">
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
-    </message>
-</context>
 <context>
     <name>WarningContent</name>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
         <translation>Програми не дозволяють вимкнути комп&apos;ютер, а примусове вимкнення може призвести до втрати даних.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
         <source>To close the program, click Cancel, and then close the program.</source>
         <translation>Щоб завершити роботу програми, натисніть кнопку «Скасувати» і закрийте вікно програми.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
         <translation>Програми не дозволяють перезавантажити комп&apos;ютер, а примусове перезавантаження може призвести до втрати даних.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
         <translation>Програми не дозволяють призупинити роботу комп&apos;ютера, а примушування призупинення може призвести до втрати даних.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
         <translation>Програми запобігають сплячому стану комп’ютера, а примушування до сплячого режиму може призвести до втрати даних.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
         <translation>Програми перешкоджають виходу з комп&apos;ютера, а примусовий вихід може призвести до втрати даних.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
         <source>Shut down</source>
         <translation>Вимкнути</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
         <source>Reboot</source>
         <translation>Перезавантажити</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
         <source>Suspend</source>
         <translation>Призупинити</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
         <source>Hibernate</source>
         <translation>Приспати</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
         <source>Log out</source>
         <translation>Вийти</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
         <source>Are you sure you want to shut down?</source>
         <translation>Ви впевнені, що хочете вимкнути компʼютер?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
         <source>Are you sure you want to reboot?</source>
         <translation>Ви впевнені, що хочете перезавантажити комп&apos;ютер?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
         <source>Are you sure you want to log out?</source>
         <translation>Ви впевнені, що хочете вийти?</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Turn on</source>
+        <translation>Увімкнути</translation>
+    </message>
+    <message>
+        <source>Turn off</source>
+        <translation>Вимкнути</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
